@@ -32,7 +32,7 @@ class Archive(io.BufferedReader):
             fileobj.name = filename
         elif isinstance(fileobj, int):
             fileobj = io.FileIO(fileobj, closefd=False)
-            fileobj.name = filename
+            fileobj.name = name
         assert isinstance(fileobj, io.IOBase), \
             "fileobj must be an instance of io.IOBase or a file, got %s" \
             % type(fileobj)
@@ -91,20 +91,20 @@ class ArchivePack(Archive):
         return len(self.members()) == 1
 
     def members(self):
-        raise NotImplemented("class %s does not implement this method" \
-            % type(self))
+        raise NotImplementedError(
+            "class %s does not implement this method" % type(self))
 
     def open(self, member):
-        raise NotImplemented("class %s does not implement this method" \
-            % type(self))
+        raise NotImplementedError(
+            "class %s does not implement this method" % type(self))
 
     def extract(self, member, path):
-        raise NotImplemented("class %s does not implement this method" \
-            % type(self))
+        raise NotImplementedError(
+            "class %s does not implement this method" % type(self))
 
     def extractall(self, path, members=None):
-        raise NotImplemented("class %s does not implement this method" \
-            % type(self))
+        raise NotImplementedError(
+            "class %s does not implement this method" % type(self))
 
 
 class ArchiveFile(Archive):
